@@ -1,7 +1,6 @@
 from clusterval.external import calculate_external
 from clusterval.internal import calculate_internal
-from clusterval.evaluate import Clusterval
-
+from clusterval.validation import Clusterval
 
 
 
