@@ -9,7 +9,7 @@ import clusterval
 from scipy.spatial.distance import euclidean
 import numpy as np
 
-def calculate_internal(data, distance_dict, clustering, indices=['all']):
+def calculate_internal(clustering, data=None, distance_dict=None, indices=['all']):
     """
     :param data: dataset being evaluated
     :param distance_dict: dictionary with distance between pairs
@@ -18,7 +18,7 @@ def calculate_internal(data, distance_dict, clustering, indices=['all']):
     :return: dictionary with indices values for a range of k number of clusters
     """
 
-    indices_funcs = {'CVNN': cvnn, 'XB': xb_improved, 'S_Dbw': s_dbw, 'DB': db_improved, 'S': silhouette, 'SD': sd,
+    indices_funcs = {'CVNN': cvnn, 'XB': xb_improved, 'SDbw': s_dbw, 'DB': db_improved, 'S': silhouette, 'SD': sd,
                      'PBM': pbm, 'Dunn': dunn}
     results = defaultdict(dict)
 
@@ -220,7 +220,7 @@ def s_dbw(clustering, data, distance_dict):
     :param clustering: dictionary with clustering results and respective centroids for each k simulation.
     :param data: dataset being analysed
     :param distance_dict: dictionary with distance between pairs
-    :return: S_Dbw index.
+    :return: SDbw index.
     '''
 
     s_dbw_index = defaultdict(float)
@@ -380,6 +380,8 @@ def silhouette(clustering, data, distance_dict):
     silhouette_index = defaultdict(float)
     for k, clusters in clustering.items():
         n_c = len(clusters['clusters'])
+        if n_c < 2:
+            raise AttributeError('Generating one single cluster. Try lowering max_k or choose another algorithem from [\'single\', \'complete\', \'ward\', \'centroid\', \'average\', \'kmeans\']')
         sum_clusters_diff = 0
         for i, cluster in enumerate(clusters['clusters']):
             n_i = len(cluster)
@@ -527,6 +529,7 @@ def pbm(clustering, data, distance_dict):
                     d_max = dist
 
         pbm_index[k] = math.pow((1/k) * (e_t/e_c) * d_max, 2)
+        
 
     return pbm_index
 
